package example;
import cs2.Button;
import cs2.TextShape;
import cs2.Window;
import cs2.WindowSide;

public class GUIAddressBook {
    /**
     * This is the View in the MVC example, the GUIAddressBook class
     * 
     */
    private static final int X_POS = 50; // X position
    private static final int Y_POS = 50; // y position
    private static final int V_OFFSET = 20; // vertical offset

    private Window window;

    private Controller controller;
    private Button switchFavBtn;
    private Button nextBtn;

    private TextShape contactCounterTS; // Contact counter TextShape
    private TextShape nameTS; // name TextShape
    private TextShape phoneTS; // phone numbers TextShape
    private TextShape favoriteTS; // favorites TextShape

    private int current = 0;


    /**
     * Constructor
     * 
     * @param controller
     *            reference to the controller
     */
    public GUIAddressBook(Controller controller) {
        this.controller = controller;

        window = new Window("MVC AddressBook Example");

        contactCounterTS = new TextShape(X_POS, Y_POS, "");
        nameTS = new TextShape(X_POS, Y_POS + V_OFFSET, "");
        phoneTS = new TextShape(X_POS, Y_POS + 2 * V_OFFSET, "");
        favoriteTS = new TextShape(X_POS, Y_POS + 3 * V_OFFSET, "");

        switchFavBtn = new Button("Switch Favorite");
        switchFavBtn.onClick(this, "switchFavClicked");

        nextBtn = new Button("Next");
        nextBtn.onClick(this, "nextClicked");

        window.addShape(contactCounterTS);
        window.addShape(nameTS);
        window.addShape(phoneTS);
        window.addShape(favoriteTS);

        window.addButton(switchFavBtn, WindowSide.SOUTH);
        window.addButton(nextBtn, WindowSide.SOUTH);

        renderGUI();

    }


    /**
     * retrieves the current Contact from the Address Book
     * and renders the GUI depicting contact details
     */
    public void renderGUI() {
        Contact cContact = controller.getContact(current);
        contactCounterTS.setText("Contact #  : " + current);
        nameTS.setText("Name       : " + cContact.getFirstName() + " "
            + cContact.getLastName());
        phoneTS.setText("Phone Nums : " + cContact.getPhoneNumbers()
            .toString());
        favoriteTS.setText("Favorite  : " + cContact.isFavorite());
    }


    /**
     * Switches the contact's favorite setting on and off
     * 
     * @param btn
     *            -the button that was clicked
     */
    public void switchFavClicked(Button btn) {
        Contact cContact = controller.getContact(current);
        System.out.println("View talks to controller");
        controller.switchContactFav(cContact);

        renderGUI();
    }


    /**
     * Changes the view to show the next contact in the list
     * 
     * @param btn
     *            -the button that was clicked
     */
    public void nextClicked(Button btn) {

        if (current < controller.getAddressBook().size() - 1) {
            current = current + 1;
        }
        else {
            // reset
            current = 0;
        }
        renderGUI();
    }

}
